@@ -12,10 +12,9 @@
  * details.
  */
 
-#include "stdafx.h"
-
 #include "OCOverlayRegistrationHandler.h"
 #include "OCOverlayFactory.h"
+#include "OverlayConstants.h"
 
 HINSTANCE instanceHandle = NULL;
 
@@ -82,8 +81,6 @@ STDAPI DllGetClassObject(REFCLSID rclsid, REFIID riid, void **ppv)
 STDAPI DllCanUnloadNow(void)
 {
     return dllReferenceCount > 0 ? S_FALSE : S_OK;
-    
-    return S_FALSE;
 }
 
 HRESULT RegisterCLSID(LPCOLESTR guidStr, PCWSTR overlayStr, PCWSTR szModule)
